@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "cc4055ff848eede21731c56714fa75095c18b55d",
-  "branchName": "release-client-5.16.1",
-  "buildTime": "2023-09-21 12:36:37 GMT",
-  "buildVersion": "5.1.733",
+  "commitId": "f95a4ef30ac8085641cb5d334605e4565c08cf0f",
+  "branchName": "release-client-5.16.x",
+  "buildTime": "2023-10-20 07:57:51 GMT",
+  "buildVersion": "836",
   "css": [
-    "@zoom/client-calendar/static/css/chunk-vendors.d4ae17e7.css",
-    "@zoom/client-calendar/static/css/app.c3b5793e.css"
+    "@zoom/client-calendar/static/css/chunk-vendors.974eca6e.css",
+    "@zoom/client-calendar/static/css/app.f1e850b6.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/chunk-vendors.5be8367f.js",
-    "@zoom/client-calendar/static/js/app.29f5ad99.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.0ec24b21.js",
+    "@zoom/client-calendar/static/js/app.4d7761b3.js"
   ],
   "key": "@zoom/client-calendar"
 };
