@@ -1,17 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "06ded6ba39876a57ea37418bac954d186bd080e6",
-  "branchName": "release-client-5.16.1",
-  "buildTime": "Tue, 19 Sep 2023 06:23:12 GMT",
-  "buildVersion": "5.1.424",
+  "commitId": "34f6cb42d67338640855eb96097302e7b72fdd24",
+  "branchName": "release-client-5.16.x",
+  "buildTime": "2023-10-19 09:07:51 GMT",
+  "buildVersion": "468",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
-    "@zoom/client-scheduler/static/css/index.f31cf0bd.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.91880f7a.css",
+    "@zoom/client-scheduler/static/css/index.6fe66edc.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.ca68f063.js",
-    "@zoom/client-scheduler/static/js/index.8779959b.js"
-  ]
+    "@zoom/client-scheduler/static/js/chunk-vendors.974f1615.js",
+    "@zoom/client-scheduler/static/js/index.ce16da06.js"
+  ],
+  "key": "@zoom/client-scheduler"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
